@@ -2,11 +2,9 @@
 #'
 #' The faux package provides functions for simulating datasets with specified structure.
 #'
-#' @docType package
 #' @name faux
-#' @keywords package
+#' @keywords internal
 #' @import ggplot2
 #' @importFrom stats cor sd
-#' 
-NULL
+"_PACKAGE"
 
